@@ -2,7 +2,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 
     SPDX-FileCopyrightText: 2003 Brian Thomas <thomas@mail630.gsfc.nasa.gov>
-    SPDX-FileCopyrightText: 2004-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2004-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #ifndef CODEGENERATOR_H
@@ -109,7 +109,7 @@ public:
 
     CodeDocument * findCodeDocumentByClassifier(UMLClassifier * classifier);
 
-    virtual QStringList defaultDatatypes();
+    virtual QStringList defaultDatatypes() const;
 
     virtual bool isReservedKeyword(const QString & keyword);
 
