@@ -1,12 +1,7 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   copyright (C) 2002-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2002-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 #include "classassociationspage.h"
 
@@ -14,7 +9,7 @@
 #include "associationpropertiesdialog.h"
 #include "debug_utils.h"
 #include "dialogpagebase.h"
-#include "listpopupmenu.h"
+#include "dialogspopupmenu.h"
 #include "umlobject.h"
 #include "umlscene.h"
 
@@ -106,7 +101,7 @@ void ClassAssociationsPage::fillListBox()
 
 void ClassAssociationsPage::slotRightButtonPressed(const QPoint &p)
 {
-    ListPopupMenu popup(this, ListPopupMenu::mt_Association_Selected);
+    DialogsPopupMenu popup(this, DialogsPopupMenu::tt_Association_Selected);
     QAction *triggered = popup.exec(m_pAssocLW->mapToGlobal(p));
     slotMenuSelection(triggered);
 }
